clld
====

Python library to support publication of cross-linguistic databases 
maintained by the `Cross Linguistic Linked Data`_ project.

Documentation is available at readthedocs_.

Code is at github_.

.. _Cross Linguistic Linked Data: http://clld.org/
.. _readthedocs: http://clld.readthedocs.org/
.. _github: https://github.com/clld/clld

.. image:: https://travis-ci.org/clld/clld.png   :target: https://travis-ci.org/clld/clld

